@@ -2,17 +2,17 @@
 #define __VIDEO_H_
 
 #include "../config.h"
+#include <string>
        
 class CVideo {
-	public:
+  public:
 	CVideo();
 	~CVideo();
-	void loadVideo(char * videoFile, SDL_Surface * videoSurf, int width , int height );
+	bool loadVideo(std::string const& videoFile, SDL_Surface* videoSurf, int width, int height );
 	void unloadVideo();
 	bool isPlaying();
-	void play(void);
-
-        private:
+	void play();
+  private:
 #ifdef USE_SMPEG
 	SMPEG *mpeg;
 	SMPEG_Info info;
